@@ -38,7 +38,7 @@ def processor(d_df, df_master, ssp_df, wacgu_dict, fy_year, month_dict):
     for month in months:
         # subset the data
         data = d_df[month].copy()
-        data['FormattedDate'] = data['ValueDate'].dt.date
+        data['FormattedDate'] = data['ValueDate'].copy()
 
         month_num = time.strptime(month, "%B").tm_mon
         year_num = fy_year - 1 if month_num > 6 else fy_year
@@ -224,7 +224,7 @@ for i in range(1, 13):
 # main wrapper function
 
 def main_execute():
-    print('Package run 26 executing...')
+    print('Package run 29 executing...')
 
     # collect the base tables
     base_table_2020, base_table_2020_Inv, base_table_2020_Deal = processor(dict_df, master_df, ssp_df, wacgu_dict,
