@@ -2,7 +2,7 @@
 This file is for setting up the global variables used throughout the project
 Customized folder paths and details to be initialized here
 '''
-
+import pyodbc
 from azure.storage.blob import BlockBlobService
 
 import pandas as pd
@@ -13,34 +13,64 @@ STORAGEACCOUNTNAME = "sttemfinancialreporting"
 STORAGEACCOUNTKEY = "ow3mO+jsdSuM7REmLnSupIOyz0mPfwayuy1lt+5UMNykhNgWKfshr6SMV9ttyVxIP9kApKwW716xRaH3GGh8Og=="
 
 
-def blob_reader(BLOBNAME, LOCALFILENAME):
+def blob_reader(BLOBNAME, LOCALFILENAME, text_reader=False):
     READ_CONTAINERNAME = "tem-db-tables"
 
     # download from blob
     blob_service = BlockBlobService(account_name=STORAGEACCOUNTNAME, account_key=STORAGEACCOUNTKEY)
-    blob_service.get_blob_to_path(READ_CONTAINERNAME, BLOBNAME, LOCALFILENAME)
 
-    dataframe_blobdata = pd.read_csv(LOCALFILENAME)
+    if text_reader:
+        blob = blob_service.get_blob_to_text(READ_CONTAINERNAME, BLOBNAME)
+        dataframe_blobdata = blob.content
+    else:
+        blob_service.get_blob_to_path(READ_CONTAINERNAME, BLOBNAME, LOCALFILENAME)
+        dataframe_blobdata = pd.read_csv(LOCALFILENAME)
 
     return dataframe_blobdata
 
 
+def read_sql(sql_conn):
+    conn = pyodbc.connect(sql_conn)
+    sql_query = pd.read_sql_query("SELECT * from Tradebook", conn)
+
+    df = pd.DataFrame(sql_query, columns=['Id', 'TradeDate', 'Direction', 'TradeType', 'Status',
+                                          'Name', 'Shares', 'Volume', 'SSP', 'Actual_Sale_Px', 'Instrument',
+                                          'Country', 'ValueDate', 'CacheDate', 'Face_SSP', 'Face_Sales',
+                                          'Counterpart', 'TEM_Margin', 'QF_Margin', 'Trader', 'Ref', 'DealRef',
+                                          'House', 'RetirementType', 'QF_PO_Reference', 'QF_PO_IssuanceDate',
+                                          'QF_InvoiceNumber', 'QF_InvoiceIssuanceDate', 'QF_InvoiceDueDate',
+                                          'QF_InvoicePaymentDate', 'TEM_InvoiceNumber', 'TEM_InvoicePaymentDate',
+                                          'RetirementReferenceNumber', 'RetirementDate', 'POS',
+                                          'TEM_InvoiceIssuanceDate',
+                                          'TEM_InvoiceDueDate'])
+
+    return df
+
+
 dataframe_ssp = blob_reader('ssp_table.csv', 'ssp_table.csv')
-dataframe_tradebook = blob_reader('tradebook.csv', 'tradebook.csv')
+
+sql_connection = blob_reader('sql_connection.txt', ' ', True)
+print(f'Read from text file successful. \n{str(sql_connection)}')
+dataframe_tradebook = read_sql(str(sql_connection))
+print(f'Read from DB successful.')
+print(f"type of {dataframe_tradebook['ValueDate'].iloc[0]} is {type(dataframe_tradebook['ValueDate'].iloc[0])}")
+
+# dataframe_tradebook = blob_reader('tradebook.csv', 'tradebook.csv')
+#
+# dataframe_tradebook['Id'] = dataframe_tradebook['Id'].astype('int')
+# dataframe_tradebook['TradeDate'] = pd.to_datetime(dataframe_tradebook['TradeDate'])
+# dataframe_tradebook['Shares'] = pd.to_numeric(dataframe_tradebook["Shares"])
+# dataframe_tradebook['Volume'] = pd.to_numeric(dataframe_tradebook["Volume"])
+# dataframe_tradebook['SSP'] = pd.to_numeric(dataframe_tradebook["SSP"])
+# dataframe_tradebook['Actual_Sale_Px'] = pd.to_numeric(dataframe_tradebook["Actual_Sale_Px"])
+# dataframe_tradebook['ValueDate'] = pd.to_datetime(dataframe_tradebook['ValueDate'])
+# dataframe_tradebook['Face_SSP'] = pd.to_numeric(dataframe_tradebook["Face_SSP"])
+# dataframe_tradebook['Face_Sales'] = pd.to_numeric(dataframe_tradebook["Face_Sales"])
+# dataframe_tradebook['TEM_Margin'] = pd.to_numeric(dataframe_tradebook["TEM_Margin"])
+# dataframe_tradebook['QF_Margin'] = pd.to_numeric(dataframe_tradebook["QF_Margin"])
+# dataframe_tradebook['House'] = dataframe_tradebook['House'].astype('bool')
+# dataframe_tradebook['POS'] = pd.to_numeric(dataframe_tradebook["POS"])
 
-dataframe_tradebook['Id'] = dataframe_tradebook['Id'].astype('int')
-dataframe_tradebook['TradeDate'] = pd.to_datetime(dataframe_tradebook['TradeDate'])
-dataframe_tradebook['Shares'] = pd.to_numeric(dataframe_tradebook["Shares"])
-dataframe_tradebook['Volume'] = pd.to_numeric(dataframe_tradebook["Volume"])
-dataframe_tradebook['SSP'] = pd.to_numeric(dataframe_tradebook["SSP"])
-dataframe_tradebook['Actual_Sale_Px'] = pd.to_numeric(dataframe_tradebook["Actual_Sale_Px"])
-dataframe_tradebook['ValueDate'] = pd.to_datetime(dataframe_tradebook['ValueDate'])
-dataframe_tradebook['Face_SSP'] = pd.to_numeric(dataframe_tradebook["Face_SSP"])
-dataframe_tradebook['Face_Sales'] = pd.to_numeric(dataframe_tradebook["Face_Sales"])
-dataframe_tradebook['TEM_Margin'] = pd.to_numeric(dataframe_tradebook["TEM_Margin"])
-dataframe_tradebook['QF_Margin'] = pd.to_numeric(dataframe_tradebook["QF_Margin"])
-dataframe_tradebook['House'] = dataframe_tradebook['House'].astype('bool')
-dataframe_tradebook['POS'] = pd.to_numeric(dataframe_tradebook["POS"])
 
 dataframe_ssp['2019'] = pd.to_numeric(dataframe_ssp["2019"])
 dataframe_ssp['2020'] = pd.to_numeric(dataframe_ssp["2020"])
@@ -50,13 +80,16 @@ dataframe_ssp['2023'] = pd.to_numeric(dataframe_ssp["2023"])
 
 dataframe_ssp.set_index("Row Labels", inplace=True)
 
+# for the spp_logic file
+filepath = ''
+sheetname = ''
+
 STATUS = ['Delivered', 'Future', 'Prospective']
 BUSINESS_LINE = ['TEM Corporate', 'TEM Bluehalo', 'Qantas FP', 'Qantas FCN']
 
 TEST_MODE = False
 
 EXCEL_FILENAME = "MVP template - June 2020.xlsx"
-# "MVP_2.xlsx"
 EXCEL_PATH = "reports/bridge/"
 
 # column mapping
